@@ -14,7 +14,7 @@
 # limitations under the License.
 #
 
-__version__ = "5.0.0"
+__version__ = "5.7.0"
 
 import argparse
 import configparser
@@ -42,6 +42,7 @@ from .global_config_validator import (
     GlobalConfigValidator,
     GlobalConfigValidatorException,
 )
+from .meta_conf import MetaConf
 from .start_alert_build import alert_build
 from .uccrestbuilder import build
 from .uccrestbuilder.global_config import (
@@ -200,8 +201,11 @@ def handle_update(config_path):
                 oauth_state_enabled_entity = {}
                 for entity in conf_entities:
                     if entity.get("field") == "oauth_state_enabled":
-                        logger.warn(
-                            "oauth_state_enabled field is no longer a separate entity since UCC version 5.0.0. It is now an option in the oauth field. Please update the globalconfig.json file accordingly."
+                        logger.warning(
+                            "oauth_state_enabled field is no longer a separate "
+                            "entity since UCC version 5.0.0. It is now an "
+                            "option in the oauth field. Please update the "
+                            "globalconfig.json file accordingly."
                         )
                         oauth_state_enabled_entity = entity
 
@@ -216,12 +220,16 @@ def handle_update(config_path):
             tab_options = tab.get("options", {})
             if tab_options.get("onChange"):
                 logger.error(
-                    "The onChange option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions."
+                    "The onChange option is no longer supported since UCC "
+                    "version 5.0.0. You can use custom hooks to implement "
+                    "these actions."
                 )
                 del tab_options["onChange"]
             if tab_options.get("onLoad"):
                 logger.error(
-                    "The onLoad option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions."
+                    "The onLoad option is no longer supported since UCC "
+                    "version 5.0.0. You can use custom hooks to implement "
+                    "these actions."
                 )
                 del tab_options["onLoad"]
 
@@ -232,12 +240,16 @@ def handle_update(config_path):
                 service_options = service.get("options", {})
                 if service_options.get("onChange"):
                     logger.error(
-                        "The onChange option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions."
+                        "The onChange option is no longer supported since UCC "
+                        "version 5.0.0. You can use custom hooks to implement "
+                        "these actions."
                     )
                     del service_options["onChange"]
                 if service_options.get("onLoad"):
                     logger.error(
-                        "The onLoad option is no longer supported since UCC version 5.0.0. You can use custom hooks to implement these actions."
+                        "The onLoad option is no longer supported since UCC "
+                        "version 5.0.0. You can use custom hooks to implement "
+                        "these actions."
                     )
                     del service_options["onLoad"]
 
@@ -309,11 +321,10 @@ def install_libs(path, ucc_lib_target):
             )
             os.system(installer + " -m pip install pip --upgrade")
             os.system(install_cmd)
-            remove_files(ucc_target)
 
     logging.info(f"  Checking for requirements in {path}")
     if os.path.exists(os.path.join(path, "lib", "requirements.txt")):
-        logging.info(f"  Uses common requirements")
+        logging.info("  Uses common requirements")
         _install_libs(
             requirements=os.path.join(path, "lib", "requirements.txt"),
             ucc_target=ucc_lib_target,
@@ -321,7 +332,7 @@ def install_libs(path, ucc_lib_target):
     elif os.path.exists(
         os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements.txt")
     ):
-        logging.info(f"  Uses common requirements")
+        logging.info("  Uses common requirements")
         _install_libs(
             requirements=os.path.join(
                 os.path.abspath(os.path.join(path, os.pardir)), "requirements.txt"
@@ -329,7 +340,7 @@ def install_libs(path, ucc_lib_target):
             ucc_target=ucc_lib_target,
         )
     else:
-        logging.info(f"  Not using common requirements")
+        logging.info("  Not using common requirements")
 
     # Prevent certain packages from being included pip could be dangerous others are just wasted space
     noshipdirs = ["setuptools", "bin", "pip", "distribute", "wheel"]
@@ -357,21 +368,6 @@ def install_libs(path, ucc_lib_target):
             os.chmod(o, current_permissions & NO_EXEC)
 
 
-def remove_files(path):
-    """
-    Remove *.egg-info and *.dist-info files in given path.
-
-    Args:
-        path (str): Path to remove *.egg-info and *.dist-info files.
-    """
-
-    rmdirs = glob.glob(os.path.join(path, "*.egg-info")) + glob.glob(
-        os.path.join(path, "*.dist-info")
-    )
-    for rmdir in rmdirs:
-        shutil.rmtree(rmdir)
-
-
 def generate_rest(ta_name, scheme, import_declare_name, outputdir):
     """
     Build REST for Add-on.
@@ -802,9 +798,17 @@ def _generate(source, config, ta_version, outputdir=None):
         ta_name, os.path.abspath(os.path.join(source, PARENT_DIR, ".uccignore"))
     )
     remove_listed_files(ignore_list)
-    logger.info("Copy package directory ")
+    logger.info("Copy package directory")
     recursive_overwrite(source, os.path.join(outputdir, ta_name))
 
+    default_meta_conf_path = os.path.join(
+        outputdir, ta_name, "metadata", "default.meta"
+    )
+    if not os.path.exists(default_meta_conf_path):
+        os.makedirs(os.path.join(outputdir, ta_name, "metadata"))
+        with open(default_meta_conf_path, "w") as default_meta_conf_fd:
+            MetaConf().create_default(default_meta_conf_fd)
+
     # Update app.manifest
     with open(os.path.join(outputdir, ta_name, "VERSION"), "w") as version_file:
         version_file.write(version_str)
@@ -866,7 +870,8 @@ def main():
     parser.add_argument(
         "--ta-version",
         type=str,
-        help="Version of TA, default version is version specified in the package such as app.manifest, app.conf, and globalConfig.json",
+        help="Version of TA, default version is version specified in the "
+        "package such as app.manifest, app.conf, and globalConfig.json",
         default=None,
     )
     args = parser.parse_args()
